@@ -1,4 +1,5 @@
 from .parameters_name_decoding_handler_option import ParametersNameDecodingHandlerOption
 from .redirect_handler_option import RedirectHandlerOption
+from .response_handler_option import ResponseHandlerOption
 from .retry_handler_option import RetryHandlerOption
-from .telemetry_handler_option import TelemetrytHandlerOption
+from .telemetry_handler_option import TelemetryHandlerOption
