@@ -3,7 +3,9 @@ from typing import Callable
 from kiota_abstractions.request_option import RequestOption
 
 
-class TelemetrytHandlerOption(RequestOption):
+class TelemetryHandlerOption(RequestOption):
+
+    TELEMETRY_HANDLER_OPTION_KEY = 'TelemetryHandlerOption'
 
     def __init__(self, telemetry_configurator: Callable[[], None]) -> None:
         self._telemetry_configurator = telemetry_configurator
@@ -15,3 +17,7 @@ class TelemetrytHandlerOption(RequestOption):
     @telemetry_configurator.setter
     def telemetry_configurator(self, value: Callable[[], None]) -> None:
         self._telemetry_configurator = value
+
+    @staticmethod
+    def get_key():
+        return TelemetryHandlerOption.TELEMETRY_HANDLER_OPTION_KEY
